@@ -1,6 +1,6 @@
 from django.apps import AppConfig
 
 
-class RockNRollConfig(AppConfig):
+class MarkdownConfig(AppConfig):
     name = 'django_bootstrap_markdown'
     verbose_name = 'Django Bootstrap Markdown'
